@@ -18,7 +18,7 @@ import random
 try:
     from collections import OrderedDict
 except ImportError:
-    OrderedDict = dict  # py26 degraded mode, expanders order wont be immutable
+    OrderedDict = dict  # py26 degraded mode, expanders order will not be immutable
 
 
 step_search_re = re.compile(r'^([^-]+)-([^-/]+)(/(\d+))?$')
@@ -31,6 +31,18 @@ hash_expression_re = re.compile(
 VALID_LEN_EXPRESSION = [5, 6]
 
 
+def timedelta_to_seconds(td):
+    return (td.microseconds + (td.seconds + td.days * 24 * 3600) * 10**6) \
+        / 10**6
+
+
+def datetime_to_timestamp(d):
+    if d.tzinfo is not None:
+        d = d.replace(tzinfo=None) - d.utcoffset()
+
+    return timedelta_to_seconds(d - datetime.datetime(1970, 1, 1))
+
+
 def _get_caller_globals_and_locals():
     """
     Returns the globals and locals of the calling frame.
@@ -149,7 +161,7 @@ class croniter(object):
         self.start_time = None
         self.dst_start_time = None
         self.cur = None
-        self.set_current(start_time)
+        self.set_current(start_time, force=False)
 
         self.expanded, self.nth_weekday_of_month = self.expand(expr_format, hash_id=hash_id)
         self._is_prev = is_prev
@@ -163,8 +175,7 @@ class croniter(object):
                 "[{0}] is not acceptable".format(" ".join(expressions)))
 
     def get_next(self, ret_type=None, start_time=None):
-        if start_time is not None:
-            self.set_current(start_time)
+        self.set_current(start_time, force=True)
         return self._get_next(ret_type or self._ret_type, is_prev=False)
 
     def get_prev(self, ret_type=None):
@@ -176,14 +187,15 @@ class croniter(object):
             return self._timestamp_to_datetime(self.cur)
         return self.cur
 
-    def set_current(self, start_time):
-        if isinstance(start_time, datetime.datetime):
-            self.tzinfo = start_time.tzinfo
-            start_time = self._datetime_to_timestamp(start_time)
+    def set_current(self, start_time, force=True):
+        if (force or (self.cur is None)) and start_time is not None:
+            if isinstance(start_time, datetime.datetime):
+                self.tzinfo = start_time.tzinfo
+                start_time = self._datetime_to_timestamp(start_time)
 
-        self.start_time = start_time
-        self.dst_start_time = start_time
-        self.cur = start_time
+            self.start_time = start_time
+            self.dst_start_time = start_time
+            self.cur = start_time
         return self.cur
 
     @classmethod
@@ -191,10 +203,7 @@ class croniter(object):
         """
         Converts a `datetime` object `d` into a UNIX timestamp.
         """
-        if d.tzinfo is not None:
-            d = d.replace(tzinfo=None) - d.utcoffset()
-
-        return cls._timedelta_to_seconds(d - datetime.datetime(1970, 1, 1))
+        return datetime_to_timestamp(d)
 
     def _timestamp_to_datetime(self, timestamp):
         """
@@ -214,10 +223,10 @@ class croniter(object):
         Note: We cannot use `timedelta.total_seconds()` because this is not
         supported by Python 2.6.
         """
-        return (td.microseconds + (td.seconds + td.days * 24 * 3600) * 10**6) \
-            / 10**6
+        return timedelta_to_seconds(td)
 
-    def _get_next(self, ret_type=None, is_prev=None):
+    def _get_next(self, ret_type=None, start_time=None, is_prev=None):
+        self.set_current(start_time, force=True)
         if is_prev is None:
             is_prev = self._is_prev
         self._is_prev = is_prev
@@ -247,7 +256,7 @@ class croniter(object):
             result = self._calc(self.cur, expanded,
                                 nth_weekday_of_month, is_prev)
 
-        # DST Handling for cron job spanning accross days
+        # DST Handling for cron job spanning across days
         dtstarttime = self._timestamp_to_datetime(self.dst_start_time)
         dtstarttime_utcoffset = (
             dtstarttime.utcoffset() or datetime.timedelta(0))
@@ -287,7 +296,7 @@ class croniter(object):
         implicit call to __iter__, whenever non-default
         'ret_type' has to be specified.
         '''
-        # In a Python 3.7+ world:  contextlib.supress and contextlib.nullcontext could be used instead
+        # In a Python 3.7+ world:  contextlib.suppress and contextlib.nullcontext could be used instead
         try:
             while True:
                 self._is_prev = False
@@ -712,7 +721,13 @@ class croniter(object):
                     except ValueError:
                         pass
 
-                    if t in cls.LOWMAP[i]:
+                    if t in cls.LOWMAP[i] and not (
+                        # do not support 0 as a month either for classical 5 fields cron
+                        # or 6fields second repeat form
+                        # but still let conversion happen if day field is shifted
+                        (i in [2, 3] and len(expressions) == 5) or
+                        (i in [3, 4] and len(expressions) == 6)
+                    ):
                         t = cls.LOWMAP[i][t]
 
                     if (
@@ -782,7 +797,7 @@ class croniter(object):
         td, ms1 = cron.get_current(datetime.datetime), relativedelta(microseconds=1)
         if not td.microsecond:
             td = td + ms1
-        cron.set_current(td)
+        cron.set_current(td, force=True)
         tdp, tdt = cron.get_current(), cron.get_prev()
         return (max(tdp, tdt) - min(tdp, tdt)).total_seconds() < 60
 
