@@ -6,7 +6,7 @@ from datetime import datetime, timedelta
 from functools import partial
 from time import sleep
 import pytz
-from croniter import (croniter, CroniterBadDateError,  CroniterBadCronError,
+from croniter import (croniter, CroniterBadDateError,  CroniterBadCronError, datetime_to_timestamp,
                       CroniterNotAlphaError, CroniterUnsupportedSyntaxError)
 from croniter.tests import base
 import dateutil.tz
@@ -1451,6 +1451,15 @@ class CroniterTest(base.TestCase):
             self.assertEqual(nt.tzinfo.zone, 'America/New_York')
             self.assertEqual(int(croniter._datetime_to_timestamp(nt)), 1547481660)
 
+    def test_issue_k12(self):
+        tz = pytz.timezone('Europe/Athens')
+        base = datetime(2010, 1, 23, 12, 18, tzinfo=tz)
+        itr = croniter('* * * * *')
+        itr.set_current(start_time=base)
+        n1 = itr.get_next()   # 19
+
+        self.assertEqual(n1, datetime_to_timestamp(base) + 60)
+
 
 if __name__ == '__main__':
     unittest.main()
